<?php
namespace OrganizationsManagement\Controller;
use Exception;
use OrganizationsManagement\Traits\TQuery;
use OrganizationsManagement\Traits\TResponse;
use OrganizationsManagement\Util\Utilities;
use Zeedhi\Framework\Controller\Simple;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DataSource;
use OrganizationsManagement\Service;
use OrganizationsManagement\Util\InstanceProvider;
use OrganizationsManagement\Service\CadastroAssunto as CadastroAssuntoService;

class CadastroAssunto extends Simple {

    use TResponse;

    /**
     * @var CadastroAssuntoService
     */
    private $cadastroAssuntoService;

    /**
     * CadastroAssuntoProduto constructor.
     * @param CadastroAssuntoService $cadastroAssuntoService
     */
    public function __construct(CadastroAssuntoService $cadastroAssuntoService)
    {
        $this->cadastroAssuntoService = $cadastroAssuntoService;
    }

    /**
     * @param DTO\Request $request
     * @param DTO\Response $response
     * @throws Exception
     */
    public function findTreeGridSubject(DTO\Request $request, DTO\Response $response){
        try{
            $data = $this->cadastroAssuntoService->findTreeGridSubject($request->getParameters());
            $this->sendResponse($data, 200);
        }catch(Exception $ex){
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function saveModalCadAssuntoAdd(DTO\Request $request, DTO\Response $response)
    {   
        try {
            $data = $request->getParameters();
            $dsassunto = $request->getParameter("DSASSUNTO");
            $paiId = !empty($data['PAI_ID']) ? $data['PAI_ID']['ID'] : null;
            $id = $request->getParameters()['ID'];
            $this->cadastroAssuntoService->saveModalCadAssuntoAdd($dsassunto, $paiId, $id);
        } catch (\Exception $ex){
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function removeSubject(DTO\Request $request, DTO\Response $response)
    {
        try {
            $datas = $request->getParameters();
            foreach ($datas["data"] as $data) {
                $id = $data["ID"];
                $this->cadastroAssuntoService->removeSubject($id);
            }
        } catch (\Exception $ex){
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }
}
