<?php

namespace OrganizationsManagement\Repository;

use Doctrine\ORM\EntityManager;
use Teknisa\Model\Traits\TQuery;

class CollectionErrors
{
    use TQuery;
    /**
     * @var EntityManager
     */
    private $entityManager;

    /**
     * @param EntityManager $entityManager
     */
    public function __construct(EntityManager $entityManager)
    {
        $this->entityManager = $entityManager;
    }

    public function getCollectionErros($parametros)
    {
        $sql = "SELECT NRSEQCONTRATO, CONTRATO, NRPARCNEGOCIO, NMPARCEIRO, ORGANIZACAOPARC, IDTIPOORG, 
                    DTINICOMPET, DTFINCOMPET, CDSERVORCA, NMSERVORCA, IDELEMENTORAIZ, NMELEMENTO, 
                    DSTIPOELEMENTO, CDTPMEDIDAVARIAVEL, DSTPMEDIDASERV, PREPSTATUS, NRORGPRINCIPAL, NMORGPRINCIPAL, 
                    QTCONTRATUAL, QTMEDIDA, QTFATURADA, DTULTIMACOLETAOM, QTULTIMAMEDIDAOM, IDSTATUS, 
                    IDSEMERRO, DSOBSCOLETA, SERVIDOR, DSSTRINGCONEXAO, IDUTWALLET, IDCOLETOR,
                    IDTPCOLETA, IDTPBANCO, IDLOCALCOLETOR, SCRIPT_COUNT_SQL, SCRIPT_LOG_SQL, SCRIPT_COUNT_PHP, 
                    SCRIPT_LOG_PHP, DTINCLUSAOERRO, NRORG, DTINCLUSAO
                FROM OM_ANALISE_COLETA(TO_DATE(:DTINICOMPET, 'DD/MM/YYYY'), /* P_DTINICIAL */
                                        TO_DATE(:DTFINCOMPET, 'DD/MM/YYYY'), /* P_DTFINAL */
                                        :NRSEQCONTRATO, /* P_NRSEQCONTRATO */
                                        :NRPARCNEGOCIO, /* P_ORGANIZACAO */
                                        :CDTPMEDIDASERV,  /* P_CDTPMEDIDAVARIAVEL */
                                        :IDELEMENTO,  /* P_IDELEMENTO */
                                        :CDSERVORCA,  /* P_CDSERVORCA */
                                        :IDTIPOORG,  /* P_IDTIPOORG */
                                        NVL(:IDSEMERRO, 'N'),  /* P_IDERRO */
                                        :IDTPCOLETA,  /* P_IDTPCOLETA */
                                        :IDSTATUS, /* P_IDSATUS*/
                                        :NRORG) /* P_NRORG */";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql, $parametros);
    }

    public function getMedidasVariaveis($parametros)
    {
        $sql = "SELECT FCT_MEDVARMEDICAOFATURA.NRMEDVARMEDICAOFATURA AS id, NVL(FCT_MEDVARMEDICAOFATURA.QTMEDIDAMEDICAO, FCT_MEDVARMEDICAOFATURA.QTMEDIDAVARIAVEL) AS count, FCT_MEDVARMEDICAOFATURA.CDTPMEDIDAVARIAVEL, FCT_TIPOMEDIDASERV.DSTPMEDIDASERV AS measureName,
                TO_CHAR(FCT_MEDICAOFATURA.DTINICOMPET, 'DD/MM/YYYY') as initCompetence, TO_CHAR(FCT_MEDICAOFATURA.DTFINCOMPET, 'DD/MM/YYYY') as endCompetence
                    FROM FCT_MEDVARMEDICAOFATURA
                    JOIN FCT_TIPOMEDIDASERV
                    ON FCT_TIPOMEDIDASERV.CDTPMEDIDASERV = FCT_MEDVARMEDICAOFATURA.CDTPMEDIDAVARIAVEL
                    JOIN FCT_MEDICAOFATURA
                    ON FCT_MEDICAOFATURA.NRMEDICAOFATURA = FCT_MEDVARMEDICAOFATURA.NRMEDICAOFATURA
                    WHERE FCT_MEDICAOFATURA.NRSEQCONTRATO = :NRSEQCONTRATO
                    AND FCT_MEDICAOFATURA.DTINICOMPET = :DTINICOMPET
                    AND FCT_MEDICAOFATURA.DTFINCOMPET = :DTFINCOMPET
                    AND FCT_MEDVARMEDICAOFATURA.IDELEMENTORAIZ = :IDELEMENTORAIZ";
 
        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql, $parametros);
    }

    public function getElementosServOrca($parametros) {
        $sql = "SELECT IDELEMENTO, NMSERVORCA FROM FCT_SERVICOORCA WHERE NRORG = :NRORG AND IDTIPO = 'E' AND IDELEMENTOPAI IS NULL";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql, $parametros);
    }

    public function getSeqContratos($parametros) {
        $sql = "SELECT NRSEQCONTRATO, NRCONTRATOFCT FROM FCT_CONTRATO WHERE NRORG = :NRORG";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql, $parametros);
    }

    public function getOrganizacaoParc($parametros) {
        $sql = "SELECT NRPARCNEGOCIO, NMPRINCIPALPARC FROM PARCNEGOCIO WHERE NRORG = :NRORG";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql, $parametros);
    }

    public function getCampoMedidaVariavel($parametros) {
        $sql = "SELECT 
                    CDTPMEDIDASERV, 
                    DSTPMEDIDASERV 
                FROM FCT_TIPOMEDIDASERV 
                WHERE IDTPMEDIDASERV = 'V' AND NRORG = :NRORG";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql, $parametros);
    }

    public function getCampoServOrca($parametros) {
        $sql = "SELECT CDSERVORCA, NMSERVORCA FROM FCT_SERVICOORCA WHERE NRORG = :NRORG AND IDTIPO = 'S'";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql, $parametros);
    }
}