<?php

namespace OrganizationsManagement\Repository;

use Doctrine\ORM\EntityManager;
use PhpOffice\PhpSpreadsheet\Calculation\LookupRef\Offset;
use Teknisa\Model\Traits\TQuery;

class OrganizationReport
{
    use TQuery;
    /**
     * @var EntityManager
     */
    private $entityManager;

    /**
     * ConsultaOperadorSAAS constructor.
     * @param EntityManager $entityManager
     */
    public function __construct(EntityManager $entityManager)
    {
        $this->entityManager = $entityManager;
    }

    public function organizationReport($elementFilter = '', $redirectionFilter = '', $dynamicFilter = '')
    {
        $query = <<<SQL
        SELECT DISTINCT *
                 FROM (SELECT DISTINCT O.IDATIVO AS ATIVO, O.NRORG, O.NMORGANIZACAO, O.NMRAZSOCIALORG,
                              OP.NMPRODUTO, OP.ID, O.DSEMAILOPER, OG.ID AS ORGID, O.PREPSTATUS AS ORGSTATUS, 
                              DECODE(O.NRORGPRINCIPAL, NULL, 'P', 'S') AS IS_PRIMARY,
                              DECODE(O.NRORGPRINCIPAL, NULL, O.IDORGSAAS, OM.IDORGSAAS) AS IDORGSAAS, OG.DSURLACESSO, O.DTINCLUSAO, 
                              OG.DSURLREDIRECT, OG.IDUTREDIRECTRC, OG.DSURLCUSTOM,
                              SP.CDPAIS, SE.SGESTADO, SM.CDMUNICIPIO, SP.NMPAIS, SE.NMESTADO, SM.NMMUNICIPIO
                         FROM ORGANIZACAO O
                    LEFT JOIN OM_PRODUTO_ORG OG ON OG.NRORG_ID = O.NRORG
                    LEFT JOIN OM_PRODUTO OP ON OP.ID = OG.NRPRODUTO_ID
                    LEFT JOIN ORGANIZACAO OM ON O.NRORGPRINCIPAL = OM.NRORG
                    LEFT JOIN OM_PRODUTO_ORG_ELEMENTO EL ON OG.ID = EL.NRPRODUTO_ORG_ID
                    LEFT JOIN PAIS SP        ON (O.CDPAIS = SP.CDPAIS)
                    LEFT JOIN ESTADO SE      ON (O.SGESTADO = SE.SGESTADO AND SE.CDPAIS = SP.CDPAIS)
                    LEFT JOIN MUNICIPIO SM   ON (O.CDMUNICIPIO = SM.CDMUNICIPIO AND O.SGESTADO = SM.SGESTADO AND SM.CDPAIS = SP.CDPAIS)
                        WHERE 1 = 1
                              $redirectionFilter
                              $elementFilter)
SQL;
        $query = $this->getFinalQueryNotBase64($query, null, null, null, null, null, $dynamicFilter);
        return $this->executeQueryAndBuildResponseData($this->entityManager, $query);
    }

    public function getOrganizationReport($projectId, $elementProductOrg)
    {
        $query = <<<SQL
    SELECT DISTINCT OP1.NMOPERADOR AS OPERINCLUSAO, OP2.NMOPERADOR AS OPERULTATU,PE.ID, PE.LABEL, PE.UNIQUE_ID,
           PE.NRPRODUTO_ID, PE.PARENT_ID, PE.NRORDEM,
           TO_CHAR(OE.DTVALIDADE, 'DD/MM/YYYY') AS DTVALIDADE,
           :elementProductOrg AS NRPRODUTO_ORG_ID,
           CASE WHEN PE.IDELEMENTOPADRAO = 'S' OR OE.ID IS NOT NULL
                THEN 'S'
                ELSE 'N'
            END AS ATIVO,
           OE.DSOBSERVACAO, OE.DTINCLUSAO, OE.DTULTATU,
           NVL2(PC.ID, 'Y', 'N') AS IS_RELATED_TO_CONTRACT,
           'Y' AS IS_SPECIFIC_ORG, PE.IDELEMENTOPADRAO, OE.ID AS ID_PRODUTO_ORG_ELEMENTO
      FROM OM_PRODUTO_ELEMENTO PE
 LEFT JOIN OM_PRODUTO_ORG_ELEMENTO OE ON OE.NRPRODUTO_ELEMENTO_ID = PE.ID
                                     AND NRPRODUTO_ORG_ID = :elementProductOrg
 LEFT JOIN OM_PRODUTO_ORG PR ON PR.ID = OE.NRPRODUTO_ORG_ID
 LEFT JOIN OPERADOR OP1 ON OE.CDOPERINCLUSAO = OP1.CDOPERADOR
 LEFT JOIN OPERADOR OP2 ON OE.CDOPERULTATU = OP2.CDOPERADOR
 LEFT JOIN OM_PROD_ORG_ELEMENTO_CONTRATO PC ON PC.NRPRODUTO_ORG_ELEMENTO_ID = OE.ID
     WHERE PE.NRPRODUTO_ID = :productId
       AND PE.ID IN (SELECT NRPRODUTO_ELEMENTO_ID 
                       FROM OM_PRODUTO_ELEMENTO_ORG_ESPEC PO
                      WHERE PO.NRPRODUTO_ELEMENTO_ID = PE.ID
                        AND PO.NRORG_ID = PR.NRORG_ID)
     UNION
    SELECT DISTINCT OP1.NMOPERADOR AS OPERINCLUSAO, OP2.NMOPERADOR AS OPERULTATU,PE.ID, PE.LABEL, PE.UNIQUE_ID,
           PE.NRPRODUTO_ID, PE.PARENT_ID, PE.NRORDEM,
           TO_CHAR(OE.DTVALIDADE, 'DD/MM/YYYY') AS DTVALIDADE,
           :elementProductOrg AS NRPRODUTO_ORG_ID,
           CASE WHEN PE.IDELEMENTOPADRAO = 'S' OR OE.ID IS NOT NULL
                THEN 'S'
                ELSE 'N'
            END AS ATIVO,
           OE.DSOBSERVACAO, OE.DTINCLUSAO, OE.DTULTATU,
           NVL2(PC.ID, 'Y', 'N') AS IS_RELATED_TO_CONTRACT,
           'N' AS IS_SPECIFIC_ORG, PE.IDELEMENTOPADRAO, OE.ID AS ID_PRODUTO_ORG_ELEMENTO
      FROM OM_PRODUTO_ELEMENTO PE
 LEFT JOIN OM_PRODUTO_ORG_ELEMENTO OE ON OE.NRPRODUTO_ELEMENTO_ID = PE.ID
                                     AND NRPRODUTO_ORG_ID = :elementProductOrg
 LEFT JOIN OM_PRODUTO_ORG PR ON PR.ID = OE.NRPRODUTO_ORG_ID
 LEFT JOIN OPERADOR OP1 ON OE.CDOPERINCLUSAO = OP1.CDOPERADOR
 LEFT JOIN OPERADOR OP2 ON OE.CDOPERULTATU = OP2.CDOPERADOR
 LEFT JOIN OM_PROD_ORG_ELEMENTO_CONTRATO PC ON PC.NRPRODUTO_ORG_ELEMENTO_ID = OE.ID
     WHERE PE.NRPRODUTO_ID = :productId
       AND PE.ID NOT IN (SELECT NRPRODUTO_ELEMENTO_ID 
                           FROM OM_PRODUTO_ELEMENTO_ORG_ESPEC PO
                          WHERE PO.NRPRODUTO_ELEMENTO_ID = PE.ID)
  ORDER BY NRORDEM
SQL;
        $params = array(
            'productId' => $projectId,
            'elementProductOrg' => $elementProductOrg
        );

        $elements =  $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $query, $params);
        $total = count($elements['data']);
        $params = ['data' => $elements['data'], 'pagination' => ['limit' => $total, 'page' => 1, 'total' => $total]];
        return $params;
    }


    public function getOrganizationReportCountry()
    {
        $query = <<<SQL
		SELECT P.CDPAIS, P.NMPAIS, P.NRORG, P.CDESOCIAL,
               CASE 
                   WHEN P.NMPAIS LIKE 'Brasil' THEN 1 ELSE 2 END AS ORDPAIS
          FROM PAIS P
         ORDER BY ORDPAIS, NMPAIS
SQL;
        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $query);
    }

    public function obtemPorIdPais($idPais)
    {
        $query = <<<SQL
    SELECT *
    FROM (
        SELECT E.SGESTADO, E.NMESTADO, E.CDPAIS
        FROM ESTADO E
        WHERE E.CDPAIS = :id
        ORDER BY E.NMESTADO
    ) ESTADO_ALIAS
SQL;

        $params = array(
            "id" => $idPais
        );
        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $query, $params);
    }

    public function obtemPorSiglaEstado($siglaEstado, $idPais)
    {
        $query = <<<SQL
        SELECT M.CDMUNICIPIO, M.NMMUNICIPIO, M.SGESTADO, E.CDPAIS
          FROM MUNICIPIO M
          JOIN ESTADO E ON M.SGESTADO = E.SGESTADO
         AND E.CDPAIS = :idPais
         WHERE M.SGESTADO = :siglaEstado
         ORDER BY M.SGESTADO
SQL;

        $params = array(
            "siglaEstado" => $siglaEstado,
            "idPais" => $idPais
        );
        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $query, $params);
    }
}
