<?php

namespace OrganizationsManagement\Service;

use Doctrine\ORM\EntityManager;
use OrganizationsManagement\Repository\Notice as NoticeRepository;
use OrganizationsManagement\Util\InstanceProvider;

class Notice
{
    /**
     * @var EntityManager
     */
    private $entityManager;
    /**
     * @var NoticeRepository
     */
    private $noticeRepository;

    /**
     * Notice constructor.
     * @param EntityManager $entityManager
     * @param NoticeRepository $NoticeRepository
     */
    public function __construct(EntityManager $entityManager, NoticeRepository $noticeRepository)
    {
        $this->entityManager = $entityManager;
        $this->noticeRepository = $noticeRepository;
    }

    public function findNotice()
    {
        return $this->noticeRepository->getNoticeRecords();
    }

    public function createNotice($data)
    {
        $connection = InstanceProvider::getEntityManager()->getConnection();
        $connection->beginTransaction();
        try {
            $environment = InstanceProvider::getLibEnvironment();
            $nrorg = $environment->getCurrentOrganizationId();
            $newCodeService = InstanceProvider::getService()->getNewCode();
            $id = $newCodeService->getCodeByTableName('INFORMATIVOECOMMERCE', $nrorg, 1, 10, true);
            $data['id'] = $id;
            $data['dateBegin'] = $data['dateBegin'] . ' 00:00:00';
            $data['dateEnd'] = $data['dateEnd'] . ' 00:00:00';
            $this->noticeRepository->insertNotice($data);
            $this->entityManager->flush();
            if (!empty($data['produto'])) {
                foreach ($data['produto'] as $produto) {
                    $cdinforproduto = $newCodeService->getCodeByTableName('INFORMATIVO_PRODUTO', $nrorg, 1, 10, true);
                    $this->noticeRepository->insertProdutoNotice($cdinforproduto, $produto, $id, $nrorg);
                }
            }
            $connection->commit();
        } catch (\Exception $e) {
            $connection->rollBack();
            throw new \Exception($e->getMessage());
        }
    }

    public function deleteNotice($ids)
    {
        $connection = InstanceProvider::getEntityManager()->getConnection();
        $connection->beginTransaction();
        try {
            foreach ($ids as $id) {
                $this->noticeRepository->deleteEcomOper($id);
                $this->noticeRepository->deleteAllProdutosNotice($connection, $id);
                $this->noticeRepository->deleteNotice($id);
            }
            $connection->commit();
        } catch (\Exception $e) {
            $connection->rollBack();
            throw new \Exception($e->getMessage());
        }
    }

    public function updateNotice($data)
    {
        $connection = InstanceProvider::getEntityManager()->getConnection();
        $connection->beginTransaction();
        $environment = InstanceProvider::getLibEnvironment();
        $nrorg = $environment->getCurrentOrganizationId();
        try {
            for ($i = 0; $i < sizeof($data); $i++) {
                $data[$i]['dateBegin'] = $data[$i]['dateBegin'] . ' 00:00:00';
                $data[$i]['dateEnd'] = $data[$i]['dateEnd'] . ' 00:00:00';
            }
            foreach ($data as $item) {
                $this->noticeRepository->updateNotice($item);
                if ($item['produtoEdit'] !== null) {
                    if (!empty($item['produtoEdit'])) {
                        $newProdutos = $item['produtoEdit'] ?? [];
                        $getCurrentProdutos = $this->noticeRepository->getProdutosByComunicadoId($item['id']);
                        $currentProdutos = $getCurrentProdutos['data'];
                        $currentProdutosArray = array_map('intval', array_column($currentProdutos, 'NRPRODUTO'));
                        $newProdutosArray = array_map('intval', $newProdutos);
                        $toRemove = array_diff($currentProdutosArray, $newProdutosArray);
                        $toAdd = array_diff($newProdutosArray, $currentProdutosArray);
                        if (!empty($toRemove)) {
                            foreach ($toRemove as $produto) {
                                $this->noticeRepository->deleteProdutosNotice($connection, $item['id'], $produto);
                            }
                        }
                        if (!empty($toAdd)) {
                            foreach ($toAdd as $produto) {
                                if (in_array($produto, $currentProdutosArray)) {
                                    continue;
                                }
                                $newCodeService = InstanceProvider::getService()->getNewCode();
                                $newId = $newCodeService->getCodeByTableName('INFORMATIVO_PRODUTO', $nrorg, 1, 10, true);
                                $this->noticeRepository->insertProdutoNotice($newId, $produto, $item['id'], $nrorg);
                            }
                        }
                    } else {
                        $this->noticeRepository->deleteAllProdutosNotice($connection, $item['id']);
                    }
                }
            }
            $connection->commit();
        } catch (\Exception $e) {
            $connection->rollBack();
            throw new \Exception($e->getMessage());
        }
    }

    public function findTimeOutnotice()
    {
        return $this->noticeRepository->getTimeOutnotice();
    }

    public function saveTimeOutNotice($parametros)
    {
        $connection = InstanceProvider::getEntityManager()->getConnection();
        $connection->beginTransaction();
        $environment = InstanceProvider::getLibEnvironment();
        $nrorg = $environment->getCurrentOrganizationId();
        $newCodeService = InstanceProvider::getService()->getNewCode();
        $cdoperador = $environment->getCdOperador();
        foreach ($parametros['ROW'] as $row) {
            $id = $row['ID'];
            $name = $row['DSNOME'];
            $qtDias = $row['QTDIAS'];
            $validate = $this->noticeRepository->validaRegistroIgual($connection, $id, $name);
            try {
                if ($id == 0) {
                    $id = $newCodeService->getCodeByTableName('INFORMATIVOECOMSILE', $nrorg, 1, 10, true);
                    if ($validate[0]["QTD"] > 0) {
                        throw new \Exception("EXISTE");
                    } else {
                        $this->noticeRepository->saveTimeOutNotice($connection, $id, $name, $qtDias, $cdoperador, $nrorg);
                    }
                } else {
                    if ($validate[0]["QTD"] > 0) {
                        throw new \Exception("EXISTE");
                    } else {
                        $this->noticeRepository->updateTimeOutNotice($connection, $id, $name, $qtDias, $cdoperador, $nrorg);
                    }
                }
                $connection->commit();
            } catch (\Exception $e) {
                $connection->rollback();
                throw $e;
            }
        }
    }

    public function deleteTimeOutNotice($parametros)
    {
        $connection = InstanceProvider::getEntityManager()->getConnection();
        $connection->beginTransaction();
        try {
            foreach ($parametros as $row) {
                $id = $row['ID'];
                $this->noticeRepository->deleteTimeOutNotice($connection, $id);
            }
            $connection->commit();
        } catch (\Exception $e) {
            $connection->rollback();
            throw $e;
        }
    }

    public function findProdutoNotice()
    {
        return $this->noticeRepository->findProdutoNotice();
    }
}
