import { Form, Modal, ModalService, DialogService, Text } from '@zeedhi/common';
import { Metadata } from '@zeedhi/core';
import { RichText } from '@zeedhi/zd-richtext-common';

export class PreViewNoticeForOperatorController {
    private modalNotificationList!: Modal;

    public getTextAnuncio: string = '';

    public originalTitle: string = '';

    public visibleIframe: boolean = false;

    public visibleText: boolean = false;

    public visibleImage: boolean = false;

    public visibleVideo: boolean = false;

    public getValueLink: string = '';

    public getValueLinkDir: string = '';

    public getTextContent: string = '';

    public visibleTextNoticeTeknisa: boolean = false;

    public getTextNoticeTeknisa: string = '';

    public publicoAlvoNotice: string = '';

    public async createdModalPreView() {
        this.modalNotificationList = await ModalService.createFromJson('noticeForOperator/preViewNoticeModal', true);
    }

    public async setIFrameDocSource(itemUrl: string) {
        const doomIframes: HTMLIFrameElement[] = Array.from(document.querySelectorAll('#preView_iframeDoc'));
        if (itemUrl) {
            doomIframes.forEach((element: HTMLIFrameElement) => {
                element.src = `${itemUrl}#zoom=76`;
            });
        } else {
            doomIframes.forEach((element: HTMLIFrameElement) => {
                element.src = '';
            });
        }
    }

    public async getLinkVideo(url: any) {
        const doomIframes: HTMLIFrameElement[] = Array.from(document.querySelectorAll('#video-basic-usage-iframe'));
        if (url) {
            doomIframes.forEach((element: HTMLIFrameElement) => {
                element.src = url;
            });
        } else {
            doomIframes.forEach((element: HTMLIFrameElement) => {
                element.src = '';
            });
        }
    }

    public async closeNotificationsModal() {
        this.modalNotificationList.hide();
        this.visibleIframe = false;
        this.visibleText = false;
        this.visibleImage = false;
        this.visibleVideo = false;
        this.visibleTextNoticeTeknisa = false;
        this.getTextAnuncio = '';
        this.originalTitle = '';
        this.getTextNoticeTeknisa = '';
        this.getValueLink = '';
        this.getValueLinkDir = '';
        this.getTextContent = '';
        this.getLinkVideo('');
        this.setIFrameDocSource('');
    }

    public async openNotificationsPre({ component }: any) {
        let form: any;
        if (component.name === 'preView-notice-button') {
            form = Metadata.getInstance<Form>('add-modal-form');
        }
        if (component.name === 'preViewEdit-notice-button') {
            form = Metadata.getInstance<Form>('view-modal-form');
        }
        const valueForm = form.value;
        this.getTextAnuncio = valueForm.title;
        this.originalTitle = this.getTextAnuncio;
        this.publicoAlvoNotice = valueForm.publicoAlvoNotice;
        if (valueForm.publicoAlvoNotice === 'T' || valueForm.publicoAlvoNotice === 'A' || valueForm.publicoAlvoNotice === 'C') {
            this.visibleTextNoticeTeknisa = true;
            this.getTextNoticeTeknisa = 'Comunicado Teknisa';
        }
        const richText = Metadata.getInstance<RichText>('rich-text');
        const contentText = richText.content;
        if (valueForm.link || contentText) {
            this.modalNotificationList.show();
            setTimeout(() => {
                this.openNotifications(valueForm, contentText);
            }, 100);
        } else {
            DialogService.show(
                {
                    name: 'nocontent_preView-dialog',
                    type: 'error',
                    title: 'Comunicado sem conteúdo',
                    text: 'O comunicado deve ter um link ou conteúdo para ser visualizado.',
                },
            );
        }
    }

    public titleNotice({ component }: any) {
        const title = Metadata.getInstance<Text>('preView-modal-title');
        if (component.currentSlide === 1) {
            title.text = 'Segundo Comunicado';
            this.visibleTextNoticeTeknisa = false;
            this.getTextNoticeTeknisa = '';
        } else if (component.currentSlide === 0) {
            if (this.publicoAlvoNotice === 'T') {
                this.visibleTextNoticeTeknisa = true;
                this.getTextNoticeTeknisa = 'Comunicado Teknisa';
            }
            title.text = this.originalTitle;
        }
    }

    public async openNotifications(valueForm: any, contentText: any) {
        if (valueForm.type === 'P') {
            this.visibleIframe = true;
            this.visibleText = false;
            this.visibleImage = false;
            this.visibleVideo = false;
            this.setIFrameDocSource(valueForm.link);
        } else if (valueForm.type === 'I') {
            this.visibleIframe = false;
            this.visibleText = false;
            this.visibleImage = true;
            this.visibleVideo = false;
            this.getValueLink = valueForm.link;
            this.getValueLinkDir = valueForm.linkDirecionamento;
        } else if (valueForm.type === 'H') {
            this.visibleIframe = false;
            this.visibleText = true;
            this.visibleImage = false;
            this.visibleVideo = false;
            this.getTextContent = contentText;
        } else if (valueForm.type === 'V') {
            this.visibleIframe = false;
            this.visibleText = true;
            this.visibleImage = false;
            this.visibleVideo = true;
            const url = this.convertToEmbedLink(valueForm.link);
            this.getLinkVideo(url);
        }
    }

    public convertToEmbedLink(url: string): string {
        const isYouTubeLink = url.includes('youtube.com') || url.includes('youtu.be');
        if (!isYouTubeLink) {
          return url;
        }
        const videoIdMatch = url.match(/(?:youtube\.com\/.*[?&]v=|youtu\.be\/)([\w-]{11})/);
        if (videoIdMatch && videoIdMatch[1]) {
          const videoId = videoIdMatch[1];
          return `https://www.youtube.com/embed/${videoId}`;
        }
        return '';
    }

    public openLinkInNewTab() {
        if (this.getValueLinkDir !== null && this.getValueLinkDir !== '') {
            window.open(this.getValueLinkDir, '_blank');
        }
    }

    public cssStyle({ component }: any) {
        if (this.getValueLinkDir !== null && this.getValueLinkDir !== '') {
            component.cssStyle = 'cursor: pointer';
        } else {
            component.cssStyle = '';
        }
    }

    public notCssStyle({ component }: any) {
        component.cssStyle = '';
    }
}
